@@ -1223,7 +1223,7 @@ prepare_attrs (HTMLText *text, HTMLPainter *painter)
 	}
 
 	if (text->links && e) {
-		HTMLColor *link_color = html_colorset_get_color (e->settings->color_set, HTMLLinkColor);
+		HTMLColor *link_color;
 		GSList *l;
 
 		for (l = text->links; l; l = l->next) {
@@ -1231,6 +1231,11 @@ prepare_attrs (HTMLText *text, HTMLPainter *painter)
 			Link *link;
 
 			link = (Link *) l->data;
+
+			if(link->is_visited == FALSE) 
+				link_color = html_colorset_get_color (e->settings->color_set, HTMLLinkColor);
+			else 
+				link_color = html_colorset_get_color (e->settings->color_set, HTMLVLinkColor);
 			attr = pango_attr_underline_new (PANGO_UNDERLINE_SINGLE);
 			attr->start_index = link->start_index;
 			attr->end_index = link->end_index;
@@ -3067,7 +3072,7 @@ html_text_append (HTMLText *text, const gchar *str, gint len)
 void
 html_text_append_link_full (HTMLText *text, gchar *url, gchar *target, gint start_index, gint end_index, gint start_offset, gint end_offset)
 {
-	text->links = g_slist_prepend (text->links, html_link_new (url, target, start_index, end_index, start_offset, end_offset));
+	text->links = g_slist_prepend (text->links, html_link_new (url, target, start_index, end_index, start_offset, end_offset, FALSE));
 }
 
 static void
@@ -3097,7 +3102,7 @@ html_text_add_link_full (HTMLText *text, HTMLEngine *e, gchar *url, gchar *targe
 	if (text->links == NULL)
 		html_text_append_link_full (text, url, target, start_index, end_index, start_offset, end_offset);
 	else {
-		Link *plink = NULL, *new_link = html_link_new (url, target, start_index, end_index, start_offset, end_offset);
+		Link *plink = NULL, *new_link = html_link_new (url, target, start_index, end_index, start_offset, end_offset, FALSE);
 
 		for (l = text->links; new_link && l; l = l->next) {
 			link = (Link *) l->data;
@@ -3313,6 +3318,7 @@ html_link_dup (Link *l)
 	nl->end_offset = l->end_offset;
 	nl->start_index = l->start_index;
 	nl->end_index = l->end_index;
+	nl->is_visited = l->is_visited;
 
 	return nl;
 }
@@ -3335,7 +3341,7 @@ html_link_equal (Link *l1, Link *l2)
 }
 
 Link *
-html_link_new (gchar *url, gchar *target, guint start_index, guint end_index, gint start_offset, gint end_offset)
+html_link_new (gchar *url, gchar *target, guint start_index, guint end_index, gint start_offset, gint end_offset, gboolean is_visited)
 {
 	Link *link = g_new0 (Link, 1);
 
@@ -3345,6 +3351,7 @@ html_link_new (gchar *url, gchar *target, guint start_index, guint end_index, gi
 	link->end_offset = end_offset;
 	link->start_index = start_index;
 	link->end_index = end_index;
+	link->is_visited = is_visited;
 
 	return link;
 }
@@ -3721,3 +3728,28 @@ html_text_direction_pango_to_html (PangoDirection pdir)
 		return HTML_DIRECTION_DERIVED;
 	}
 }
+
+void
+html_text_change_set (HTMLText *text, HTMLChangeFlags flags)
+{
+	HTMLObject *slave = HTML_OBJECT (text)->next;
+
+	for (; slave && HTML_IS_TEXT_SLAVE (slave) && HTML_TEXT_SLAVE (slave)->owner == text; slave = slave->next)
+		slave->change |= flags;
+
+	html_object_change_set (HTML_OBJECT (text), flags);
+}
+
+void
+html_text_set_link_visited (HTMLText *text, gint offset, HTMLEngine *engine, gboolean is_visited)
+{
+        HTMLEngine *object_engine=html_object_engine(HTML_OBJECT(text),engine); 
+        Link *link = html_text_get_link_at_offset (text,offset);
+
+	if (link) {
+                link->is_visited  = is_visited;
+                html_text_change_set (text, HTML_CHANGE_RECALC_PI);
+                html_text_queue_draw (text, object_engine, offset, 1);
+                html_engine_flush_draw_queue (object_engine);
+        }
+}
